==> ikapi-2.1.7.tgz: package/src/Database/DDB/IKDBQueryGet.js <==
import IKDBBaseQuery from './IKDBBaseQuery';
import Utils from './../../API/IKUtils';
//
export default class IKDBQueryGet extends IKDBBaseQuery {
  constructor(optIndexName) {
    super(optIndexName);
    this.limit = -1;
    this.lastEvaluatedKey = null;
  }
  async run(dbManager, appendingItems) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const resp = await this.rawRun(dbManager, appendingItems);
    if (resp.Items) {
      let unmarshalled = Utils.decapsulateForDB(resp.Items);
      localConsole.debug('Parsed result: ', unmarshalled);
      //Check for appending items from previous query
      if (appendingItems && appendingItems.length > 0) {
        unmarshalled = unmarshalled.concat(appendingItems);
      }
      //Check for continuation
      this.lastEvaluatedKey = resp.LastEvaluatedKey;
      if (resp.LastEvaluatedKey && !(this.limit > 0 && unmarshalled.length == this.limit)) {
        localConsole.debug('Using continuation key:', resp.LastEvaluatedKey);
        this.exclusiveStartKey = resp.LastEvaluatedKey;
        return this.run(dbManager, unmarshalled);
      } return unmarshalled;
    } return null;
  }
  async rawRun(dbManager, appendingItems) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const query = {
      ...this._rawQuery(dbManager.tableName),
      ...(this.limit > 0 ? { Limit: this.limit - (appendingItems ? appendingItems.length : 0) } : {})
    };
    localConsole.log('Querying: ', query);
    const resp = await dbManager.connection.query(query).promise();
    localConsole.debug('Raw result: ', resp);
    return resp;
  }
}

==> ikapi-2.4.4.tgz: package/src/Database/DDB/IKDBQueryGet.js <==
import IKDBBaseQuery from './IKDBBaseQuery';
import Utils from './../../API/IKUtils';
//
export default class IKDBQueryGet extends IKDBBaseQuery {
  constructor(optIndexName) {
    super(optIndexName);
    this.limit = -1;
    this.lastEvaluatedKey = null;
    this.scanIndexForward = true;
  }
  async run(dbManager, appendingItems) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const resp = await this.rawRun(dbManager, appendingItems);
    if (resp.Items) {
      let unmarshalled = Utils.decapsulateForDB(resp.Items);
      localConsole.debug('Parsed result: ', unmarshalled);
      //Check for appending items from previous query
      if (appendingItems && appendingItems.length > 0) {
        unmarshalled = unmarshalled.concat(appendingItems);
      }
      //Check for continuation
      this.lastEvaluatedKey = resp.LastEvaluatedKey;
      if (resp.LastEvaluatedKey && !(this.limit > 0 && unmarshalled.length == this.limit)) {
        localConsole.debug('Using continuation key:', resp.LastEvaluatedKey);
        this.exclusiveStartKey = resp.LastEvaluatedKey;
        return this.run(dbManager, unmarshalled);
      } return unmarshalled;
    } return null;
  }
  async rawRun(dbManager, appendingItems) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const query = {
      ...this._rawQuery(dbManager.tableName),
      ...(this.limit > 0 ? { Limit: this.limit - (appendingItems ? appendingItems.length : 0) } : {}),
      ...(!this.scanIndexForward ? { ScanIndexForward: false } : {}),
    };
    localConsole.log('Querying: ', query);
    const resp = await dbManager.connection.query(query).promise();
    localConsole.debug('Raw result: ', resp);
    return resp;
  }
}
